pygeodesy.heights._HeightIDW

Package pygeodesy :: Module heights :: Class _HeightIDW |
[frames] | no frames]

# Class _HeightIDW

      object --+
               |
    named._Named --+
                   |
        _HeightNamed --+
                       |
                      _HeightIDW

Known Subclasses:
  - HeightIDWcosineLaw
  - , HeightIDWdistanceTo
  - , HeightIDWequirectangular
  - , HeightIDWeuclidean
  - , HeightIDWexact
  - , HeightIDWflatLocal
  - , HeightIDWflatPolar
  - , HeightIDWhaversine
  - , HeightIDWkarney
  - , HeightIDWthomas
  - , HeightIDWvincentys

(INTERNAL) Base class for Inverse Distance Weighting (IDW) height interpolators.

See Also: IDW, SHEPARD_INTERP_2D and other `_HeightIDW*` classes.

Instance Methods
__init__(self, knots, beta=2, **name__kwds) New `_HeightIDW*` interpolator. |
__call__(self, *llis, **wrap) Interpolate the height for one or several locations. |
height(self, lats, lons, **wrap) Interpolate the height for one or several lat-/longitudes. |
Inherited from `_HeightNamed`: `height_` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| adjust Get the `adjust` setting (`bool`) or `None`.
| beta Get the inverse distance power (`int`).
| datum Get the `datum` setting or the default (Datum).
| hypot Get the `hypot` setting (`callable`) or `None`.
| knots Get the `knots` (`list` or `tuple`).
| kwds Get the optional keyword arguments (`dict`).
| limit Get the `limit` setting (`degrees`) or `None`.
| radius Get the `radius` setting (`bool`) or `None`.
| scaled Get the `scaled` setting (`bool`) or `None`.
| wrap Get the `wrap` setting or the default (`bool`) or `None`.
Inherited from `_HeightNamed`: `kmin` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, knots, beta=2, **name__kwds) (Constructor) |
New `_HeightIDW*` interpolator. Arguments: `knots` - The points with known height (`LatLon`s). `beta` - Inverse distance power (`int` 1, 2, or 3). `name__kwds` - Optional `name=NN` for this height interpolator (`str`) and any keyword arguments for the distance function, retrievable with property `kwds`. Raises: `HeightError` - Insufficient number of `knots` or an invalid `knot` or `beta`. Overrides: object.__init__

### __call__ (self, *llis, **wrap) (Call operator) |
Interpolate the height for one or several locations. Arguments: `llis` - One or more locations (`LatLon`s), all positional. `wrap` - If `True`, wrap or normalize all `llis` locations (`bool`). Returns: A single interpolated height (`float`) or a list or tuple of interpolated heights (`float`s). Raises: `HeightError` - Insufficient number of `llis`, an invalid `lli` or pygeodesy.fidw issue. Overrides: _HeightNamed.__call__

### height (self, lats, lons, **wrap) |
Interpolate the height for one or several lat-/longitudes. Arguments: `lats` - Latitude or latitudes (each `degrees`). `lons` - Longitude or longitudes (each `degrees`). `wrap` - Keyword argument `wrap=False` (`bool`). Use `wrap=True` to wrap or normalize all `lats` and `lons`. Returns: A single interpolated height (`float`) or a list of interpolated heights (each `float`). Raises: `HeightError` - Insufficient or unequal number of `lats` and `lons` or a pygeodesy.fidw issue. Overrides: _HeightNamed.height

Property Details

### adjust Get the `adjust` setting (`bool`) or `None`. Get method: adjust(self) - Get the `adjust` setting (`bool`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### beta Get the inverse distance power (`int`). Get method: beta(self) - Get the inverse distance power (`int`). Set method: beta(self, beta) - Set the inverse distance power (`int` 1, 2, or 3).

### datum Get the `datum` setting or the default (Datum). Get method: datum(self) - Get the `datum` setting or the default (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### hypot Get the `hypot` setting (`callable`) or `None`. Get method: hypot(self) - Get the `hypot` setting (`callable`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### knots Get the `knots` (`list` or `tuple`). Get method: knots(self) - Get the `knots` (`list` or `tuple`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### kwds Get the optional keyword arguments (`dict`). Get method: kwds(self) - Get the optional keyword arguments (`dict`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### limit Get the `limit` setting (`degrees`) or `None`. Get method: limit(self) - Get the `limit` setting (`degrees`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### radius Get the `radius` setting (`bool`) or `None`. Get method: radius(self) - Get the `radius` setting (`bool`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### scaled Get the `scaled` setting (`bool`) or `None`. Get method: scaled(self) - Get the `scaled` setting (`bool`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### wrap Get the `wrap` setting or the default (`bool`) or `None`. Get method: wrap(self) - Get the `wrap` setting or the default (`bool`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.